@@ -139,6 +139,23 @@ def import_dump_postgresql(dump):
     env.method('PGPASSWORD=%(PASSWORD)s psql -U %(USER)s %(NAME)s < ' % env.postgresql + dump)
 
 
+# ====================================================================================================
+# Crontabs
+# ====================================================================================================
+@task(alias='cron-add')
+def crontab_add():
+    dj('crontab add')
+
+
+@taks(alias='cron-rm')
+def crontab_remove():
+    dj('crontab remove)
+
+
+@task(alias='cron-list')
+def crontab_list():
+    sh('crontab -l')
+
 # ====================================================================================================
 # Supervisor
 # ====================================================================================================
